==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/id.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Dokumen",
    "Can't create document" : "Tidak dapat membuat dokumen",
    "You don't have permission to rename this document" : "Anda tidak memiliki izin untuk mengubah nama dokumen ini",
    "Directory saved successfully." : "Direktori berhasil disimpan.",
    "An error occurred while changing directory." : "Terjadi kesalahan saatt mengubah direktori.",
    "Saved" : "Disimpan",
    "Format filter server is down or misconfigured" : "Server penyaring format mati atau salah konfigurasi",
    "Conversion failed. Check log for details." : "Konversi gagal. Lihat log untuk rincian.",
    "Saving..." : "Menyimpan...",
    "Failed to load documents." : "Gagal untuk memuat dokumen.",
    "No documents were found. Upload or create a document to get started!" : "Tidak ada dokumen yang ditemukan. Unggah atau buat sebuah dokumen untuk memulai!",
    "No connection to server. Trying to reconnect." : "Tidak tersambung ke server. Coba untuk menyambungkan ulang.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Meninggalkan halaman ini dalam mode Penyunting menyebabkan data tidak disimpan. Direkomendasikan untuk menggunakan tombol 'Tutup' sebagai gantinya.",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "Gagal memuat dokumen ini. Silakan periksa apakah ini dapat dibuka dengan penyunting odt eksternal. Dokumen ini mungkin saja sudah tidak dibagikan kepada Anda atau sudah dihapus baru-baru ini.",
    "Save" : "Simpan",
    "Loading documents..." : "Memuat dokumen...",
    "'.' is an invalid file name." : "'.' bukan nama berkas yang valid.",
    "File name cannot be empty." : "Nama berkas tidak boleh kosong.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Nama tidak valid, karakter '\\', '/', '<', '>', ':', '\"', '|', '?' dan '*' tidak diizinkan.",
    "Align Left" : "Rata kiri",
    "Alignment" : "Rata Kiri Kanan",
    "Align Right" : "Rata kanan",
    "Annotate" : "Keterangan",
    "Background" : "Latar belakang",
    "Bold" : "Tebal",
    "Bottom" : "Tombol",
    "Cancel" : "Batal",
    "Center" : "Tengah",
    "Clone" : "Duplikat",
    "Clone this Style" : "Duplikat gaya ini",
    "Close" : "Tutup",
    "Color" : "Warna",
    "Create" : "Buat",
    "Decrease Indent" : "Perkecil Indentasi",
    "Default Style" : "Gaya bawaan",
    "Delete" : "Hapus",
    "Family" : "Keluarga",
    "Font" : "Huruf",
    "Font Effects" : "Efek huruf",
    "Format" : "Format",
    "Increase Indent" : "Perbesar Indentasi",
    "Insert Image" : "Sisipkan Gambar",
    "Invite Members" : "Undang Anggota",
    "Italic" : "Miring",
    "Justified" : "Rata Kiri Kanan",
    "Justify" : "Ratakan",
    "Left" : "Kiri",
    "Loading" : "Memuat",
    "Members" : "Anggota",
    "New Name:" : "Nama Baru",
    "OK" : "Oke",
    "Open" : "Buka",
    "Options" : "Opsi",
    "Paragraph..." : "Paragraf...",
    "Paragraph Styles" : "Gaya Paragraf",
    "Redo" : "Batal",
    "Right" : "Kanan",
    "Size" : "Ukuran",
    "Spacing" : "Spasi",
    "Strikethrough" : "Coret",
    "Style" : "Gaya",
    "Text" : "Teks",
    "Top" : "Atas",
    "Underline" : "Garis bawah",
    "Undo" : "Batal",
    "Unknown Author" : "Penulis tidak diketahui",
    "Edit" : "Edit",
    "Share" : "Bagikan",
    "guest" : "pengunjung",
    "MS Word support (requires openOffice/libreOffice)" : "Dukungan MS Word (memerlukan openOffice/libreOffice)",
    "Local" : "Lokal",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "openOffice/libreOffice sudah terinstal pada server ini. Jalur lokasi biner disediakan via preview_libreoffice_path didalam config.php",
    "External" : "Eksternal",
    "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/libreOffice sudah terinstal pada server eksternal menjalankan server penyaring format",
    "Disabled" : "Dinonaktifkan",
    "scheme://domain.tld[:port]" : "scheme://domain.tld[:port]",
    "Server URL" : "URL Server",
    "Apply and test" : "Terapkan dan uji coba",
    "New document" : "Dokumen Baru",
    "Upload (max. %s)" : "Unggah (maks. %s)",
    "Upload" : "Unggah",
    "Save new documents to" : "Simpan dokumen ke",
    "Wrong password. Please retry." : "Sandi salah. Silakan ulangi.",
    "Password" : "Sandi",
    "Guest %s" : "Pengunjung %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Tautan ini sudah kadaluarsa atau tidak pernah ada. Silahkan hubungi orang yang berbagi dengan Anda untuk lebih rinci.",
    "Advanced feature-set" : "Set fitur lanjutan",
    "(Unstable)" : "(Tidak stabil)"
},
"nplurals=1; plural=0;");

==> owncloud-app-documents-1%3A0.13.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/id.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Dokumen",
    "Can't create document" : "Tidak dapat membuat dokumen",
    "You don't have permission to rename this document" : "Anda tidak memiliki izin untuk mengubah nama dokumen ini",
    "Directory saved successfully." : "Direktori berhasil disimpan.",
    "An error occurred while changing directory." : "Terjadi kesalahan saatt mengubah direktori.",
    "Saved" : "Disimpan",
    "Format filter server is down or misconfigured" : "Server penyaring format mati atau salah konfigurasi",
    "Conversion failed. Check log for details." : "Konversi gagal. Lihat log untuk rincian.",
    "Saving..." : "Menyimpan...",
    "Failed to load documents." : "Gagal untuk memuat dokumen.",
    "No documents were found. Upload or create a document to get started!" : "Tidak ada dokumen yang ditemukan. Unggah atau buat sebuah dokumen untuk memulai!",
    "No connection to server. Trying to reconnect." : "Tidak tersambung ke server. Coba untuk menyambungkan ulang.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Meninggalkan halaman ini dalam mode Penyunting menyebabkan data tidak disimpan. Direkomendasikan untuk menggunakan tombol 'Tutup' sebagai gantinya.",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "Gagal memuat dokumen ini. Silakan periksa apakah ini dapat dibuka dengan penyunting odt eksternal. Dokumen ini mungkin saja sudah tidak dibagikan kepada Anda atau sudah dihapus baru-baru ini.",
    "Save" : "Simpan",
    "Loading documents..." : "Memuat dokumen...",
    "'.' is an invalid file name." : "'.' bukan nama berkas yang valid.",
    "File name cannot be empty." : "Nama berkas tidak boleh kosong.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Nama tidak valid, karakter '\\', '/', '<', '>', ':', '\"', '|', '?' dan '*' tidak diizinkan.",
    "Align Left" : "Rata kiri",
    "Alignment" : "Rata Kiri Kanan",
    "Align Right" : "Rata kanan",
    "Annotate" : "Keterangan",
    "Background" : "Latar belakang",
    "Bold" : "Tebal",
    "Bottom" : "Tombol",
    "Cancel" : "Batal",
    "Center" : "Tengah",
    "Clone" : "Duplikat",
    "Clone this Style" : "Duplikat gaya ini",
    "Close" : "Tutup",
    "Color" : "Warna",
    "Create" : "Buat",
    "Decrease Indent" : "Perkecil Indentasi",
    "Default Style" : "Gaya bawaan",
    "Delete" : "Hapus",
    "Family" : "Keluarga",
    "Font" : "Huruf",
    "Font Effects" : "Efek huruf",
    "Format" : "Format",
    "Increase Indent" : "Perbesar Indentasi",
    "Insert Image" : "Sisipkan Gambar",
    "Invite Members" : "Undang Anggota",
    "Italic" : "Miring",
    "Justified" : "Rata Kiri Kanan",
    "Justify" : "Ratakan",
    "Left" : "Kiri",
    "Loading" : "Memuat",
    "Members" : "Anggota",
    "New Name:" : "Nama Baru",
    "OK" : "Oke",
    "Open" : "Buka",
    "Options" : "Opsi",
    "Paragraph..." : "Paragraf...",
    "Paragraph Styles" : "Gaya Paragraf",
    "Redo" : "Batal",
    "Right" : "Kanan",
    "Size" : "Ukuran",
    "Spacing" : "Spasi",
    "Strikethrough" : "Coret",
    "Style" : "Gaya",
    "Text" : "Teks",
    "Top" : "Atas",
    "Underline" : "Garis bawah",
    "Undo" : "Batal",
    "Unknown Author" : "Penulis tidak diketahui",
    "Shared" : "Dibagikan",
    "Error" : "Kesalahan",
    "Error while sharing" : "Kesalahan saat membagikan",
    "Error while unsharing" : "Kesalahan saat membatalkan pembagian",
    "Error while changing permissions" : "Kesalahan saat mengubah izin",
    "Shared with you and the group {group} by {owner}" : "Dibagikan dengan anda dan grup {group} oleh {owner}",
    "Shared with you by {owner}" : "Dibagikan dengan anda oleh {owner}",
    "Share with users or groups …" : "Bagikan dengan pengguna atau grup ...",
    "Share with users, groups or remote users …" : "Bagikan dengan pengguna, grup atau pengguna remote ...",
    "Share" : "Bagikan",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Bagikan dengan orang lain di ownCloud menggunakan sintaks username@example.com/owncloud",
    "Share link" : "Bagikan tautan",
    "The public link will expire no later than {days} days after it is created" : "Tautan publik akan kadaluarsa tidak lebih dari {days} hari setelah ini dibuat",
    "Link" : "Tautan",
    "Password protect" : "Lindungi dengan sandi",
    "Password" : "Sandi",
    "Choose a password for the public link" : "Tetapkan sandi untuk tautan publik",
    "Allow editing" : "Izinkan penyuntingan",
    "Email link to person" : "Emailkan tautan ini ke orang",
    "Send" : "Kirim",
    "Set expiration date" : "Atur tanggal kedaluwarsa",
    "Expiration" : "Kedaluwarsa",
    "Expiration date" : "Tanggal kedaluwarsa",
    "An error occured. Please try again" : "Terjadi masalah. Mohon coba kembali",
    "Adding user..." : "Menambahkan pengguna...",
    "group" : "grup",
    "remote" : "remote",
    "Resharing is not allowed" : "Berbagi ulang tidak diizinkan",
    "Shared in {item} with {user}" : "Dibagikan dalam {item} dengan {user}",
    "Unshare" : "Batalkan berbagi",
    "notify by email" : "notifikasi via email",
    "can share" : "dapat berbagi",
    "can edit" : "dapat disunting",
    "access control" : "kontrol akses",
    "create" : "buat",
    "change" : "ubah",
    "delete" : "hapus",
    "Password protected" : "Sandi dilindungi",
    "Error unsetting expiration date" : "Kesalahan saat menghapus tanggal kedaluwarsa",
    "Error setting expiration date" : "Kesalahan saat mengatur tanggal kedaluwarsa",
    "Sending ..." : "Mengirim ...",
    "Email sent" : "Email terkirim",
    "Warning" : "Peringatan",
    "Edit" : "Edit",
    "guest" : "pengunjung",
    "MS Word support (requires openOffice/libreOffice)" : "Dukungan MS Word (memerlukan openOffice/libreOffice)",
    "Local" : "Lokal",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "openOffice/libreOffice sudah terinstal pada server ini. Jalur lokasi biner disediakan via preview_libreoffice_path didalam config.php",
    "External" : "Eksternal",
    "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/libreOffice sudah terinstal pada server eksternal menjalankan server penyaring format",
    "Disabled" : "Dinonaktifkan",
    "No MS Word support" : "Tidak ada dukungan MS Word",
    "scheme://domain.tld[:port]" : "scheme://domain.tld[:port]",
    "Server URL" : "URL Server",
    "Apply and test" : "Terapkan dan uji coba",
    "New document" : "Dokumen Baru",
    "Upload (max. %s)" : "Unggah (maks. %s)",
    "Upload" : "Unggah",
    "Save new documents to" : "Simpan dokumen ke",
    "Wrong password. Please retry." : "Sandi salah. Silakan ulangi.",
    "Guest %s" : "Pengunjung %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Tautan ini sudah kadaluarsa atau tidak pernah ada. Silahkan hubungi orang yang berbagi dengan Anda untuk lebih rinci.",
    "Advanced feature-set" : "Set fitur lanjutan",
    "(Unstable)" : "(Tidak stabil)"
},
"nplurals=1; plural=0;");
